@@ -1,12 +1,13 @@
 import glob
 import json
 import datetime
+import os.path as path
 from dateutil.rrule import rrule, MONTHLY, SA
 
 import configbuilder.from_csv
 
 output_file = "config.json"
-
+configs_path = "configs{0}".format(path.sep)
 
 def _ordinal_suffix(day):
     if 4 <= day <= 20 or 24 <= day <= 30:
@@ -30,7 +31,7 @@ def main():
     data_parts = glob.glob("configs/*.csv")
     data = { }
     for part in data_parts:
-        key = part.replace("configs\\", "").replace(".csv", "")
+        key = part.replace(configs_path, "").replace(".csv", "")
         data[key] = configbuilder.from_csv.main(part)
 
     boilerplate = json.load(open("configs/boiler.json"))
